========================
wagtail-streamfieldtools
========================

A suite of tools that extends `Wagtail <https://wagtail.io/>`_'s already-awesome `StreamField <http://docs.wagtail.io/en/latest/topics/streamfield.html>`_ to make it even more flexible/versatile/useful!

Includes:

- A simple interface for displaying the individual blocks of a ``StreamField`` in any number of renditions.
- A 'block registry' (and its associated field, ``RegisteredBlockStreamField``) that makes blocks pluggable/re-usable across disparate models/apps/projects.

TODO:

- Docs (with useful, easy-to-follow examples)!
- Tests!
